@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,7 +25,7 @@
 
 #include <QWidget>
 #include <QLabel>
-#include <QDomNode>
+#include <QXmlStreamReader>
 #include "libksieve_debug.h"
 #include <QGridLayout>
 
@@ -67,40 +67,38 @@ QWidget *SieveActionAddHeader::createParamWidget(QWidget *parent) const
     return w;
 }
 
-bool SieveActionAddHeader::setParamWidgetValue(const QDomElement &element, QWidget *w, QString &error)
+bool SieveActionAddHeader::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
 {
     int index = 0;
-    QDomNode node = element.firstChild();
-    while (!node.isNull()) {
-        QDomElement e = node.toElement();
-        if (!e.isNull()) {
-            const QString tagName = e.tagName();
-            if (tagName == QLatin1String("tag")) {
-                SelectAddHeaderPositionCombobox *combo = w->findChild<SelectAddHeaderPositionCombobox *>(QStringLiteral("selectposition"));
-                combo->setCode(AutoCreateScriptUtil::tagValue(e.text()), name(), error);
-            } else if (tagName == QLatin1String("str")) {
-                if (index == 0) {
-                    QLineEdit *edit = w->findChild<QLineEdit *>(QStringLiteral("headeredit"));
-                    edit->setText(e.text());
-                } else if (index == 1) {
-                    QLineEdit *value = w->findChild<QLineEdit *>(QStringLiteral("valueedit"));
-                    value->setText(AutoCreateScriptUtil::quoteStr(e.text()));
-                } else {
-                    tooManyArgument(tagName, index, 2, error);
-                    qCDebug(LIBKSIEVE_LOG) << " SieveActionAddHeader::setParamWidgetValue too many argument :" << index;
-                }
-                ++index;
-            } else if (tagName == QLatin1String("crlf")) {
-                //nothing
-            } else if (tagName == QLatin1String("comment")) {
-                //implement in the future ?
+    while (element.readNextStartElement()) {
+        const QStringRef tagName = element.name();
+        if (tagName == QLatin1String("tag")) {
+            SelectAddHeaderPositionCombobox *combo = w->findChild<SelectAddHeaderPositionCombobox *>(QStringLiteral("selectposition"));
+            combo->setCode(AutoCreateScriptUtil::tagValue(element.readElementText()), name(), error);
+        } else if (tagName == QLatin1String("str")) {
+            if (index == 0) {
+                QLineEdit *edit = w->findChild<QLineEdit *>(QStringLiteral("headeredit"));
+                edit->setText(element.readElementText());
+            } else if (index == 1) {
+                QLineEdit *value = w->findChild<QLineEdit *>(QStringLiteral("valueedit"));
+                value->setText(AutoCreateScriptUtil::quoteStr(element.readElementText()));
             } else {
-                unknownTag(tagName, error);
-                qCDebug(LIBKSIEVE_LOG) << "SieveActionAddHeader::setParamWidgetValue unknown tag " << tagName;
+                tooManyArgument(tagName, index, 2, error);
+                qCDebug(LIBKSIEVE_LOG) << " SieveActionAddHeader::setParamWidgetValue too many argument :" << index;
             }
+            ++index;
+        } else if (tagName == QLatin1String("crlf")) {
+            element.skipCurrentElement();
+            //nothing
+        } else if (tagName == QLatin1String("comment")) {
+            element.skipCurrentElement();
+            //implement in the future ?
+        } else {
+            unknownTag(tagName, error);
+            qCDebug(LIBKSIEVE_LOG) << "SieveActionAddHeader::setParamWidgetValue unknown tag " << tagName;
         }
-        node = node.nextSibling();
     }
+
     return true;
 }
 
@@ -115,7 +113,11 @@ QString SieveActionAddHeader::code(QWidget *w) const
     const QLineEdit *value = w->findChild<QLineEdit *>(QStringLiteral("valueedit"));
     const QString valueStr = value->text();
 
-    return QStringLiteral("addheader %1 \"%2\" \"%3\";").arg(position, headerStr, valueStr);
+    if (position.isEmpty()) {
+        return QStringLiteral("addheader \"%1\" \"%2\";").arg(headerStr, valueStr);
+    } else {
+        return QStringLiteral("addheader %1 \"%2\" \"%3\";").arg(position, headerStr, valueStr);
+    }
 }
 
 QString SieveActionAddHeader::help() const
