@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,17 +20,15 @@
 #define SIEVEACTIONDISCARD_H
 
 #include "sieveaction.h"
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveActionDiscard : public SieveAction
 {
     Q_OBJECT
 public:
-    explicit SieveActionDiscard(QObject *parent = Q_NULLPTR);
-    static SieveAction *newAction();
-    QString code(QWidget *) const Q_DECL_OVERRIDE;
-    QString help() const Q_DECL_OVERRIDE;
-    QUrl href() const Q_DECL_OVERRIDE;
+    explicit SieveActionDiscard(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent = nullptr);
+    QString code(QWidget *) const override;
+    QString help() const override;
+    QUrl href() const override;
 };
 }
 
