@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -37,7 +37,7 @@ public:
     QUrl href() const override;
     void setLocalVariable(QWidget *w, const SieveGlobalVariableActionWidget::VariableElement &var);
 private:
-    bool mHasRegexCapability;
+    bool mHasRegexCapability = false;
 };
 }
 
