@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -17,17 +17,22 @@
    Boston, MA 02110-1301, USA.
 */
 #include "addresslineedit.h"
-
+#include <KLocalizedString>
 #include <KColorScheme>
+#include <QHBoxLayout>
 
 using namespace KSieveUi;
 
 AddressLineEdit::AddressLineEdit(QWidget *parent)
-    : QLineEdit(parent)
-    , mIncorrectEmail(false)
+    : AbstractSelectEmailLineEdit(parent)
 {
-    setClearButtonEnabled(true);
-    connect(this, &AddressLineEdit::textChanged, this, &AddressLineEdit::slotTextChanged);
+    QHBoxLayout *mainLayout = new QHBoxLayout(this);
+    mainLayout->setMargin(0);
+    mLineEdit = new QLineEdit(this);
+    mainLayout->addWidget(mLineEdit);
+    mLineEdit->setClearButtonEnabled(true);
+    mLineEdit->setPlaceholderText(i18n("Define Email Address..."));
+    connect(mLineEdit, &QLineEdit::textChanged, this, &AddressLineEdit::slotTextChanged);
 }
 
 AddressLineEdit::~AddressLineEdit()
@@ -36,9 +41,7 @@ AddressLineEdit::~AddressLineEdit()
 
 void AddressLineEdit::slotTextChanged()
 {
-    if (mIncorrectEmail) {
-        verifyAddress();
-    }
+    verifyAddress();
     Q_EMIT valueChanged();
 }
 
@@ -46,23 +49,35 @@ void AddressLineEdit::verifyAddress()
 {
 #ifndef QT_NO_STYLE_STYLESHEET
     QString styleSheet;
-    if (!text().isEmpty()) {
-        mIncorrectEmail = !text().contains(QLatin1Char('@'));
-        //TODO improve check
+    const QString lineEditText = text();
+    if (!lineEditText.isEmpty()) {
+        const bool incorrectEmail = !lineEditText.contains(QLatin1Char('@'));
+        //Fix check multi address
         if (mNegativeBackground.isEmpty()) {
             KStatefulBrush bgBrush = KStatefulBrush(KColorScheme::View, KColorScheme::NegativeText);
             mNegativeBackground = QStringLiteral("QLineEdit{ color:%1 }").arg(bgBrush.brush(this).color().name());
         }
-        if (mIncorrectEmail) {
+        if (incorrectEmail) {
             styleSheet = mNegativeBackground;
         }
     }
-    setStyleSheet(styleSheet);
+    mLineEdit->setStyleSheet(styleSheet);
 #endif
 }
 
 void AddressLineEdit::focusOutEvent(QFocusEvent *ev)
 {
     verifyAddress();
-    QLineEdit::focusOutEvent(ev);
+    AbstractSelectEmailLineEdit::focusOutEvent(ev);
+}
+
+
+void AddressLineEdit::setText(const QString &str)
+{
+    mLineEdit->setText(str);
+}
+
+QString AddressLineEdit::text() const
+{
+    return mLineEdit->text();
 }
