@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -87,7 +87,7 @@ class SieveIncludeWidgetLister : public KPIM::KWidgetLister
     Q_OBJECT
 public:
     explicit SieveIncludeWidgetLister(QWidget *parent = nullptr);
-    ~SieveIncludeWidgetLister();
+    ~SieveIncludeWidgetLister() override;
 
     void generatedScript(QString &script, QStringList &requires);
     void loadScript(QXmlStreamReader &element, QString &error);
