@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -265,8 +265,8 @@ void SieveScriptBlockWidget::loadScript(QXmlStreamReader &element, bool onlyActi
             const QStringRef tagName = element.name();
             if (tagName == QLatin1String("test")) {
                 bool notCondition = false;
-                if (element.attributes().hasAttribute(QStringLiteral("name"))) {
-                    const QString typeCondition = element.attributes().value(QStringLiteral("name")).toString();
+                if (element.attributes().hasAttribute(QLatin1String("name"))) {
+                    const QString typeCondition = element.attributes().value(QLatin1String("name")).toString();
                     if (typeCondition == QLatin1String("anyof")) {
                         mMatchCondition = OrCondition;
                     } else if (typeCondition == QLatin1String("allof")) {
