@@ -1,4 +1,4 @@
-/* Copyright (C) 2011-2017 Laurent Montel <montel@kde.org>
+/* Copyright (C) 2011-2018 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -21,6 +21,7 @@
 #include "sieveeditorwidget.h"
 
 #include <KLocalizedString>
+#include <KMessageBox>
 
 #include <QPushButton>
 #include <QKeyEvent>
@@ -34,13 +35,11 @@ class KSieveUi::SieveEditorPrivate
 {
 public:
     SieveEditorPrivate()
-        : mSieveEditorWidget(nullptr)
-        , mOkButton(nullptr)
     {
     }
 
-    SieveEditorWidget *mSieveEditorWidget;
-    QPushButton *mOkButton;
+    SieveEditorWidget *mSieveEditorWidget = nullptr;
+    QPushButton *mOkButton = nullptr;
 };
 
 SieveEditor::SieveEditor(QWidget *parent)
@@ -101,6 +100,11 @@ bool SieveEditor::event(QEvent *e)
     return QDialog::event(e);
 }
 
+void SieveEditor::setModified(bool b)
+{
+    d->mSieveEditorWidget->setModified(b);
+}
+
 void SieveEditor::slotEnableButtonOk(bool b)
 {
     d->mOkButton->setEnabled(b);
@@ -161,6 +165,11 @@ void SieveEditor::setSieveCapabilities(const QStringList &capabilities)
     d->mSieveEditorWidget->setSieveCapabilities(capabilities);
 }
 
+void SieveEditor::setListOfIncludeFile(const QStringList &listOfIncludeFile)
+{
+    d->mSieveEditorWidget->setListOfIncludeFile(listOfIncludeFile);
+}
+
 void SieveEditor::addFailedMessage(const QString &err)
 {
     d->mSieveEditorWidget->addFailedMessage(err);
@@ -175,3 +184,15 @@ void SieveEditor::addNormalMessage(const QString &msg)
 {
     d->mSieveEditorWidget->addNormalMessage(msg);
 }
+
+void SieveEditor::closeEvent(QCloseEvent *e)
+{
+    if (d->mSieveEditorWidget->originalScript() != d->mSieveEditorWidget->script()) {
+        if (KMessageBox::No == KMessageBox::warningYesNo(this, i18n("Script is modified. Do you want to close editor ?"))) {
+            e->ignore();
+            return;
+        }
+    }
+    Q_EMIT cancelClicked();
+    e->accept();
+}
