@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -29,7 +29,7 @@ public:
     explicit SieveTextEditorSpellCheckDecorator(SieveTextEdit *plainTextEdit);
     bool isSpellCheckingEnabledForBlock(const QString &textBlock) const override;
 private:
-    SieveTextEdit *mPlainTextEdit;
+    SieveTextEdit *mPlainTextEdit = nullptr;
 };
 }
 #endif // SIEVETEXTEDITORSPELLCHECKDECORATOR_H
