@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -46,9 +46,9 @@ public Q_SLOTS:
 private:
     void initialize(KSieveUi::SieveTextEdit *custom = nullptr);
     SieveTextEditWidgetPrivate *const d;
-    KSieveUi::SieveTextEdit *mTextEdit;
-    KPIMTextEdit::SlideContainer *mSliderContainer;
-    KPIMTextEdit::PlainTextEditFindBar *mFindBar;
+    KSieveUi::SieveTextEdit *mTextEdit = nullptr;
+    KPIMTextEdit::SlideContainer *mSliderContainer = nullptr;
+    KPIMTextEdit::PlainTextEditFindBar *mFindBar = nullptr;
 };
 }
 #endif // SIEVETEXTEDITWIDGET_H
