@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -32,7 +32,7 @@ class SieveTemplateListWidget : public PimCommon::TemplateListWidget
     Q_OBJECT
 public:
     explicit SieveTemplateListWidget(const QString &configName, QWidget *parent = nullptr);
-    ~SieveTemplateListWidget();
+    ~SieveTemplateListWidget() override;
 
     QVector<PimCommon::defaultTemplate> defaultTemplates() override;
     bool addNewTemplate(QString &templateName, QString &templateScript) override;
@@ -42,7 +42,7 @@ protected:
     QMimeData *mimeData(const QList<QListWidgetItem *> items) const override;
 private:
     QStringList mCapabilities;
-    PimCommon::TemplateManager *mTemplateManager;
+    PimCommon::TemplateManager *mTemplateManager = nullptr;
 };
 
 class SieveTemplateWidget : public QWidget
@@ -57,7 +57,7 @@ Q_SIGNALS:
     void insertTemplate(const QString &);
 
 private:
-    SieveTemplateListWidget *mListTemplate;
+    SieveTemplateListWidget *mListTemplate = nullptr;
 };
 }
 
