@@ -1,7 +1,7 @@
 /*
     vacationdialog.cpp
 
-    Copyright (c) 2013-2017 Laurent Montel <montel@kde.org>
+    Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
     Copyright (c) 2002 Marc Mutz <mutz@kde.org>
 
     This program is free software; you can redistribute it and/or
@@ -227,6 +227,11 @@ void VacationDialog::setEndTime(const QTime &endTime)
     mVacationEditWidget->setEndTime(endTime);
 }
 
+void VacationDialog::setSieveImapAccountSettings(const SieveImapAccountSettings &account)
+{
+    mVacationEditWidget->setSieveImapAccountSettings(account);
+}
+
 QDate VacationDialog::startDate() const
 {
     return mVacationEditWidget->startDate();
