@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -50,6 +50,8 @@ typedef QVector<AddrSpec> AddrSpecList;
 }
 
 namespace KSieveUi {
+class VacationMailActionWidget;
+class SieveImapAccountSettings;
 class VacationEditWidget : public QWidget
 {
     Q_OBJECT
@@ -100,6 +102,7 @@ public:
     VacationUtils::MailAction mailAction() const;
     QString mailActionRecipient() const;
     void setMailAction(VacationUtils::MailAction action, const QString &recipient);
+    void setSieveImapAccountSettings(const KSieveUi::SieveImapAccountSettings &account);
 
     void setDefault();
 
@@ -108,24 +111,24 @@ private Q_SLOTS:
     void mailActionChanged(int index);
 
 protected:
-    QCheckBox *mActiveCheck;
-    QSpinBox *mIntervalSpin;
-    QLineEdit *mMailAliasesEdit;
-    KPIMTextEdit::PlainTextEditorWidget *mTextEdit;
-    QCheckBox *mSpamCheck;
-    QCheckBox *mDomainCheck;
-    QLineEdit *mDomainEdit;
-    QLineEdit *mSubject;
-    QComboBox *mMailAction;
-    QLineEdit *mMailActionRecipient;
-    KDateComboBox *mStartDate;
-    KTimeComboBox *mStartTime;
-    QCheckBox *mStartTimeActive;
-    QLabel *mStartDateLabel;
-    KDateComboBox *mEndDate;
-    KTimeComboBox *mEndTime;
-    QCheckBox *mEndTimeActive;
-    QLabel *mEndDateLabel;
+    QCheckBox *mActiveCheck = nullptr;
+    QSpinBox *mIntervalSpin = nullptr;
+    QLineEdit *mMailAliasesEdit = nullptr;
+    KPIMTextEdit::PlainTextEditorWidget *mTextEdit = nullptr;
+    QCheckBox *mSpamCheck = nullptr;
+    QCheckBox *mDomainCheck = nullptr;
+    QLineEdit *mDomainEdit = nullptr;
+    QLineEdit *mSubject = nullptr;
+    QComboBox *mMailAction = nullptr;
+    VacationMailActionWidget *mMailActionRecipient = nullptr;
+    KDateComboBox *mStartDate = nullptr;
+    KTimeComboBox *mStartTime = nullptr;
+    QCheckBox *mStartTimeActive = nullptr;
+    QLabel *mStartDateLabel = nullptr;
+    KDateComboBox *mEndDate = nullptr;
+    KTimeComboBox *mEndTime = nullptr;
+    QCheckBox *mEndTimeActive = nullptr;
+    QLabel *mEndDateLabel = nullptr;
 };
 }
 
