@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -21,7 +21,7 @@
 #include "ksieveui/vacation/vacationcreatescriptjob.h"
 
 #include <QWidget>
-
+#include <QPointer>
 #include <KLocalizedString>
 #include <KMessageBox>
 
@@ -32,16 +32,13 @@ class KSieveUi::VacationManagerPrivate
 public:
     VacationManagerPrivate(QWidget *parent)
         : mWidget(parent)
-        , mMultiImapVacationDialog(nullptr)
-        , mCheckVacation(nullptr)
-        , mQuestionAsked(false)
     {
     }
 
-    QWidget *mWidget;
-    QPointer<KSieveUi::MultiImapVacationDialog> mMultiImapVacationDialog;
-    QPointer<KSieveUi::MultiImapVacationManager> mCheckVacation;
-    bool mQuestionAsked;
+    QWidget *mWidget = nullptr;
+    QPointer<KSieveUi::MultiImapVacationDialog> mMultiImapVacationDialog = nullptr;
+    QPointer<KSieveUi::MultiImapVacationManager> mCheckVacation = nullptr;
+    bool mQuestionAsked = false;
 };
 
 VacationManager::VacationManager(SieveImapPasswordProvider *passwordProvider, QWidget *parent)
