@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -116,7 +116,7 @@ void VacationPageWidget::slotGetResult(const QString &serverName, const QStringL
                            << scriptName << "(" << active << ")" << endl;
 
     if (mUrl.scheme() == QStringLiteral("sieve")
-        && !sieveCapabilities.contains(QStringLiteral("vacation"))) {
+        && !sieveCapabilities.contains(QLatin1String("vacation"))) {
         mStackWidget->setCurrentIndex(ScriptNotSupported);
         return;
     }
@@ -125,7 +125,7 @@ void VacationPageWidget::slotGetResult(const QString &serverName, const QStringL
     mUrl.setPath(mUrl.path() + scriptName);
 
     // Whether the server supports the "date" extension
-    mHasDateSupport = mUrl.scheme() == QStringLiteral("sieve") && sieveCapabilities.contains(QStringLiteral("date"));
+    mHasDateSupport = mUrl.scheme() == QStringLiteral("sieve") && sieveCapabilities.contains(QLatin1String("date"));
 
     KSieveUi::VacationUtils::Vacation vacation = KSieveUi::VacationUtils::parseScript(script);
 
