@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -22,7 +22,6 @@
 #include <QUrl>
 class QStackedWidget;
 namespace KManageSieve {
-class SieveJob;
 }
 
 namespace KSieveUi {
@@ -30,7 +29,7 @@ class VacationEditWidget;
 class VacationWarningWidget;
 class VacationCreateScriptJob;
 class MultiImapVacationManager;
-class ParseUserScriptJob;
+class SieveImapAccountSettings;
 class VacationPageWidget : public QWidget
 {
     Q_OBJECT
@@ -43,6 +42,7 @@ public:
     KSieveUi::VacationCreateScriptJob *writeScript();
     void setDefault();
     void setVacationManager(MultiImapVacationManager *vacationManager);
+    void setSieveImapAccountSettings(const KSieveUi::SieveImapAccountSettings &account);
 
 private Q_SLOTS:
     void slotGetResult(const QString &serverName, const QStringList &sieveCapabilities, const QString &scriptName, const QString &script, bool active);
@@ -58,13 +58,13 @@ private:
 
     QString mServerName;
     QUrl mUrl;
-    QStackedWidget *mStackWidget;
-    VacationEditWidget *mVacationEditWidget;
-    VacationWarningWidget *mVacationWarningWidget;
-    MultiImapVacationManager *mVacationManager;
+    QStackedWidget *mStackWidget = nullptr;
+    VacationEditWidget *mVacationEditWidget = nullptr;
+    VacationWarningWidget *mVacationWarningWidget = nullptr;
+    MultiImapVacationManager *mVacationManager = nullptr;
     PageType mPageScript;
-    bool mWasActive;
-    bool mHasDateSupport;
+    bool mWasActive = false;
+    bool mHasDateSupport = false;
 };
 }
 
